===================
Octavia Contributor
===================

Contributor Guidelines
----------------------
.. toctree::
   :glob:
   :maxdepth: 1

   CONSTITUTION.rst
   HACKING.rst

Contributor Reference
---------------------
.. toctree::
   :glob:
   :maxdepth: 1

   guides/*
   devref/*


Internal APIs
-------------
.. toctree::
   :glob:
   :maxdepth: 1

   api/*

Design Documentation
--------------------

Version 0.5 (liberty)
`````````````````````
.. toctree::
   :glob:
   :maxdepth: 1

   design/version0.5/*

Project Specifications
----------------------

Version 0.5 (liberty)
`````````````````````
.. toctree::
   :glob:
   :maxdepth: 1

   specs/version0.5/*

Version 0.8 (mitaka)
````````````````````
.. toctree::
   :glob:
   :maxdepth: 1

   specs/version0.8/*

Version 0.9 (newton)
````````````````````
.. toctree::
   :glob:
   :maxdepth: 1

   specs/version0.9/*

Version 1.0 (pike)
``````````````````
.. toctree::
   :glob:
   :maxdepth: 1

   specs/version1.0/*

Indices and Search
------------------

.. toctree::
   :hidden:

   modules/modules

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
